@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Padre::Plugin ();
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 our @ISA     = 'Padre::Plugin';
 
 # Child modules we need to unload when disabled
@@ -14,12 +14,12 @@ use constant CHILDREN => qw{
 	Padre::Plugin::Moose::Role::CanHandleInspector
 	Padre::Plugin::Moose::Role::CanProvideHelp
 	Padre::Plugin::Moose::Role::HasClassMembers
+	Padre::Plugin::Moose::Role::NeedsSaveAsEvent
 	Padre::Plugin::Moose::Attribute
 	Padre::Plugin::Moose::Class
 	Padre::Plugin::Moose::ClassMember
 	Padre::Plugin::Moose::Constructor
 	Padre::Plugin::Moose::Destructor
-	Padre::Plugin::Moose::Document
 	Padre::Plugin::Moose::Method
 	Padre::Plugin::Moose::Program
 	Padre::Plugin::Moose::Role
@@ -31,9 +31,6 @@ use constant CHILDREN => qw{
 	Padre::Plugin::Moose::FBP::Preferences
 };
 
-# Store the current configuration object for _plugin_config consumers
-my $config;
-
 # Called when Padre wants to check what package versions this
 # plugin needs
 sub padre_interfaces {
@@ -47,27 +44,17 @@ sub padre_interfaces {
 		;
 }
 
-# Called when Padre wants to knows what documents this Plugin supports
-sub registered_documents {
-	'application/x-perl' => 'Padre::Plugin::Moose::Document',;
-}
-
 # Called when Padre wants a name for the plugin
 sub plugin_name {
 	Wx::gettext('Moose');
 }
 
-# Called by Padre::Plugin::Moose::Document to retrieve configuration
-sub _plugin_config {
-	return $config;
-}
-
 # Called when the plugin is enabled by Padre
 sub plugin_enable {
 	my $self = shift;
 
 	# Read the plugin configuration, and
-	$config = $self->config_read;
+	my $config = $self->config_read;
 	unless ( defined $config ) {
 
 		# No configuration, let us create it
@@ -78,15 +65,15 @@ sub plugin_enable {
 	unless ( defined $config->{type} ) {
 		$config->{type} = 'Moose';
 	}
+	unless ( defined $config->{namespace_autoclean} ) {
+		$config->{namespace_autoclean} = 0;
+	}
 	unless ( defined $config->{comments} ) {
 		$config->{comments} = 1;
 	}
 	unless ( defined $config->{sample_code} ) {
 		$config->{sample_code} = 1;
 	}
-	unless ( defined $config->{snippets} ) {
-		$config->{snippets} = 1;
-	}
 
 	# Write the plugin's configuration
 	$self->config_write($config);
@@ -94,6 +81,11 @@ sub plugin_enable {
 	# Update configuration attribute
 	$self->{config} = $config;
 
+	# Hook up to Padre's save-as event
+	# TODO remove once Padre 0.96 is released
+	require Padre::Plugin::Moose::Role::NeedsSaveAsEvent;
+	Padre::Plugin::Moose::Role::NeedsSaveAsEvent->meta->apply( $self->main );
+
 	return 1;
 }
 
@@ -151,6 +143,32 @@ sub show_assistant {
 	return;
 }
 
+# Called when an editor is opened
+sub editor_enable {
+	my $self     = shift;
+	my $editor   = shift;
+	my $document = shift;
+
+	# Only on Perl documents
+	return unless $document->isa('Padre::Document::Perl');
+
+	require Padre::Plugin::Moose::Util;
+	Padre::Plugin::Moose::Util::add_moose_keywords_highlighting( $self->{config}->{type}, $document, $editor );
+}
+
+# Called when an editor is changed
+sub editor_changed {
+	my $self     = shift;
+	my $document = $self->current->document or return;
+	my $editor   = $self->current->editor or return;
+
+	# Only on Perl documents
+	return unless $document->isa('Padre::Document::Perl');
+
+	require Padre::Plugin::Moose::Util;
+	Padre::Plugin::Moose::Util::add_moose_keywords_highlighting( $self->{config}->{type}, $document, $editor );
+}
+
 1;
 
 __END__
@@ -169,25 +187,26 @@ Then use it via L<Padre>, The Perl IDE. Press F8.
 
 =head1 DESCRIPTION
 
-Once you enable this Plugin under Padre, you'll get a brand new menu with the following options:
+Once you enable this Plugin under Padre, you'll get a brand new menu with the
+following options:
 
 =head2 Moose Assistant
 
-Opens up a user-friendly dialog where you can add classes, roles, attributes, subtypes and methods.
-The dialog contains a tree of class/role elements that are created while it is open and a preview of
-generated Perl code. It also contains links to Moose manual, cookbook and website.
+Opens up a user-friendly dialog where you can add classes, roles and their
+members. The dialog contains a tree view of created class and role elements and
+a preview of the generated Perl code. It also contains links to Moose online
+references.
 
 =head2 Moose Preferences
 
-TODO describe Moose Preferences
-
-=head2 TextMate-style TAB triggered snippets
-
-TODO describe TextMate-style TAB triggered snippets
+Provides the ability to change the operation type (Moose, Mouse or 
+MooseX::Declare) and toggle the usage of namespace::clean, comments and sample 
+usage code generation.
 
 =head2 Keyword Syntax Highlighting
 
-TODO describe Keyword Syntax Highlighting
+Moose/Mouse and MooseX::Declare keywords are highlighted automatically in any
+Perl document. The operation type determines what to highlight.
 
 =head1 BUGS
 
