@@ -1,9 +1,8 @@
 package Padre::Plugin::Moose::Class;
 
 use Moose;
-use namespace::clean;
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 with 'Padre::Plugin::Moose::Role::CanGenerateCode';
 with 'Padre::Plugin::Moose::Role::HasClassMembers';
@@ -18,14 +17,13 @@ has 'namespace_autoclean' => ( is => 'rw', isa => 'Bool' );
 has 'singleton'           => ( is => 'rw', isa => 'Bool' );
 
 sub generate_moose_code {
-	my $self     = shift;
-	my $options  = shift;
-	my $comments = $options->{comments};
-
+	my $self                = shift;
+	my $options             = shift;
+	my $comments            = $options->{comments};
+	my $namespace_autoclean = $options->{namespace_autoclean};
 	my $class               = $self->name;
 	my $superclasses        = $self->superclasses;
 	my $roles               = $self->roles;
-	my $namespace_autoclean = $self->namespace_autoclean;
 	my $make_immutable      = $self->immutable;
 
 	$class        =~ s/^\s+|\s+$//g;
@@ -83,21 +81,28 @@ sub generate_moose_code {
 			? " # Makes it faster at the cost of startup time\n"
 			: "\n";
 	}
-	$code .= "\n1;\n\n";
+
+	if ($namespace_autoclean) {
+		$code .= "\n1;\n\n";
+	} else {
+		if ( scalar @{ $self->subtypes } ) {
+			$code .= "\nno Moose::Util::TypeConstraints;\n";
+		}
+		$code .= "\nno Moose;\n1;\n\n";
+	}
 
 	return $code;
 }
 
 # Generate Mouse code!
 sub generate_mouse_code {
-	my $self     = shift;
-	my $options  = shift;
-	my $comments = $options->{comments};
-
+	my $self                = shift;
+	my $options             = shift;
+	my $comments            = $options->{comments};
+	my $namespace_autoclean = $options->{namespace_autoclean};
 	my $class               = $self->name;
 	my $superclasses        = $self->superclasses;
 	my $roles               = $self->roles;
-	my $namespace_autoclean = $self->namespace_autoclean;
 	my $make_immutable      = $self->immutable;
 
 	$class        =~ s/^\s+|\s+$//g;
@@ -144,21 +149,27 @@ sub generate_mouse_code {
 			? " # Makes it faster at the cost of startup time\n"
 			: "\n";
 	}
-	$code .= "\n1;\n\n";
+
+	if ($namespace_autoclean) {
+		$code .= "\n1;\n\n";
+	} else {
+		if ( scalar @{ $self->subtypes } ) {
+			$code .= "\nno Mouse::Util::TypeConstraints;\n";
+		}
+		$code .= "\nno Mouse;\n1;\n\n";
+	}
 
 	return $code;
 }
 
 sub generate_moosex_declare_code {
-	my $self     = shift;
-	my $options  = shift;
-	my $comments = $options->{comments};
-
-	my $class               = $self->name;
-	my $superclasses        = $self->superclasses;
-	my $roles               = $self->roles;
-	my $namespace_autoclean = $self->namespace_autoclean;
-	my $make_immutable      = $self->immutable;
+	my $self           = shift;
+	my $options        = shift;
+	my $comments       = $options->{comments};
+	my $class          = $self->name;
+	my $superclasses   = $self->superclasses;
+	my $roles          = $self->roles;
+	my $make_immutable = $self->immutable;
 
 	$class        =~ s/^\s+|\s+$//g;
 	$superclasses =~ s/^\s+|\s+$//g;
@@ -169,7 +180,7 @@ sub generate_moosex_declare_code {
 
 	# If there is at least one subtype, we need to add this import
 	if ( scalar @{ $self->subtypes } ) {
-		$class_body .= "use Mouse::Util::TypeConstraints;\n";
+		$class_body .= "use Moose::Util::TypeConstraints;\n";
 	}
 
 	# Generate class members
@@ -185,7 +196,8 @@ sub generate_moosex_declare_code {
 	my $with    = ( scalar @roles )       ? "with ($roles) "           : q{};
 	my $mutable = $make_immutable         ? q{}                        : "is mutable ";
 
-	return "use MooseX::Declare;\nclass $class $extends$with$mutable\{\n$class_body\n}\n\n";
+	# namespace::autoclean is implicit in { }
+	return "use MooseX::Declare;\nclass $class $extends$with$mutable\{\n$class_body\n}\n";
 }
 
 sub provide_help {
@@ -200,7 +212,7 @@ sub read_from_inspector {
 	my $grid = shift;
 
 	my $row = 0;
-	for my $field (qw(name superclasses roles immutable namespace_autoclean singleton)) {
+	for my $field (qw(name superclasses roles immutable singleton)) {
 		$self->$field( $grid->GetCellValue( $row++, 1 ) );
 	}
 }
@@ -210,7 +222,7 @@ sub write_to_inspector {
 	my $grid = shift;
 
 	my $row = 0;
-	for my $field (qw(name superclasses roles immutable namespace_autoclean singleton)) {
+	for my $field (qw(name superclasses roles immutable singleton)) {
 		$grid->SetCellValue( $row++, 1, $self->$field );
 	}
 }
@@ -222,11 +234,11 @@ sub get_grid_data {
 		{ name => Wx::gettext('Superclasses:') },
 		{ name => Wx::gettext('Roles:') },
 		{ name => Wx::gettext('Make immutable?'), is_bool => 1 },
-		{ name => Wx::gettext('Clean namespace?'), is_bool => 1 },
 		{ name => Wx::gettext('Singleton?'), is_bool => 1 },
 	];
 }
 
 __PACKAGE__->meta->make_immutable;
 
+no Moose;
 1;
