@@ -1,13 +1,13 @@
 package Padre::Plugin::Moose::ClassMember;
 
 use Moose;
-use namespace::clean;
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 has 'name' => ( is => 'rw', isa => 'Str' );
 
 __PACKAGE__->meta->make_immutable;
 
+no Moose;
 1;
 
