@@ -1,9 +1,8 @@
 package Padre::Plugin::Moose::Subtype;
 
 use Moose;
-use namespace::clean;
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 extends 'Padre::Plugin::Moose::ClassMember';
 
@@ -82,4 +81,5 @@ sub get_grid_data {
 
 __PACKAGE__->meta->make_immutable;
 
+no Moose;
 1;
