@@ -4,12 +4,12 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 sub add_moose_keywords_highlighting {
-	my $document = shift;
 	my $type     = shift or return;
-	my $editor   = $document->editor or return;
+	my $document = shift or return;
+	my $editor   = shift or return;
 
 	my $keywords = Padre::Wx::Scintilla->keywords($document);
 	if ( Params::Util::_ARRAY($keywords) ) {
